@@ -1,7 +1,11 @@
-"""Configuration values, access, and management
+"""venra.config
+
+A module for accessing and managing config for venra itself.
 
 The default configuration targets a local, single-node instance of Vespa with
 all standard ports and configuration.
+
+
 """
 
 import os
@@ -11,12 +15,12 @@ import os
 # Configuration
 #------------------------------------------------------------------------------
 
-# Vespa
+# Main endpoints
 vespa_host_cfg = "http://127.0.0.1:19071"
 vespa_host_app = "http://127.0.0.1:8080"
 
-# Venra
-baz = True
+# http client
+timeout_s = 3.5
 
 
 #------------------------------------------------------------------------------
